@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
 import re
+import time
 from tmdbv3api import TMDb, Movie, TV, Search, Find
-# from tmdbv3api.objs.find import Find
 
 from torcp import tortitle
 from torcp.torcategory import TorCategory
 
+GENRE_LIST_en = [{'id': 28, 'name': 'Action'}, {'id': 12, 'name': 'Adventure'}, {'id': 16, 'name': 'Animation'}, {'id': 35, 'name': 'Comedy'}, {'id': 80, 'name': 'Crime'}, {'id': 99, 'name': 'Documentary'}, {'id': 18, 'name': 'Drama'}, {'id': 10751, 'name': 'Family'}, {'id': 14, 'name': 'Fantasy'}, {
+    'id': 36, 'name': 'History'}, {'id': 27, 'name': 'Horror'}, {'id': 10402, 'name': 'Music'}, {'id': 9648, 'name': 'Mystery'}, {'id': 10749, 'name': 'Romance'}, {'id': 878, 'name': 'Science Fiction'}, {'id': 10770, 'name': 'TV Movie'}, {'id': 53, 'name': 'Thriller'}, {'id': 10752, 'name': 'War'}, {'id': 37, 'name': 'Western'}]
+GENRE_LIST_cn = [{'id': 28, 'name': '动作'}, {'id': 12, 'name': '冒险'}, {'id': 16, 'name': '动画'}, {'id': 35, 'name': '喜剧'}, {'id': 80, 'name': '犯罪'}, {'id': 99, 'name': '纪录'}, {'id': 18, 'name': '剧情'}, {'id': 10751, 'name': '家庭'}, {'id': 14, 'name': '奇幻'}, {
+    'id': 36, 'name': '历史'}, {'id': 27, 'name': '恐怖'}, {'id': 10402, 'name': '音乐'}, {'id': 9648, 'name': '悬疑'}, {'id': 10749, 'name': '爱情'}, {'id': 878, 'name': '科幻'}, {'id': 10770, 'name': '电视电影'}, {'id': 53, 'name': '惊悚'}, {'id': 10752, 'name': '战争'}, {'id': 37, 'name': '西部'}]
 
 def transFromCCFCat(cat):
     if re.match(r'(Movie)', cat, re.I):
@@ -83,6 +87,7 @@ class TMDbNameParser():
         self.popularity = 0
         self.poster_path = ''
         self.genre_ids =[]
+        self.tmdbDetails = None
 
     def parse(self, torname, useTMDb=False, hasIMDbId=None, hasTMDbId=None):
         self.clearData()
@@ -105,24 +110,82 @@ class TMDbNameParser():
         self.tmdbcat = transFromCCFCat(self.ccfcat)
 
         if useTMDb:
-            if hasTMDbId:
-                cat, tmdbstr = parseTMDbStr(hasTMDbId)
-                if tmdbstr:
-                    tmdbid, title, year = self.searchTMDbByTMDbId(cat, tmdbstr)
-                    if tmdbid > 0:
-                        print(tmdbid, title, self.ccfcat, self.year)
-                        return True
-            if hasIMDbId:
-                tmdbid, title, year = self.searchTMDbByIMDbId(hasIMDbId)
-                if tmdbid > 0:
-                    print(tmdbid, title, self.ccfcat, self.year)
-                    return
-            if not self.checkNameContainsId(torname):
-                if self.tmdbcat in ['tv', 'movie', 'Other', 'HDTV']:
-                    self.searchTMDb(self.title, self.tmdbcat,
-                                    parseYear, self.cntitle)
-            self.ccfcat = transToCCFCat(self.tmdbcat, self.ccfcat)
-            
+            attempts = 0
+            while attempts < 3:
+                try:
+                    if hasTMDbId:
+                        cat, tmdbstr = parseTMDbStr(hasTMDbId)
+                        if tmdbstr:
+                            tmdbid, title, year = self.searchTMDbByTMDbId(cat, tmdbstr)
+                            if tmdbid > 0:
+                                print(tmdbid, title, self.ccfcat, self.year)
+                                return True
+                    if hasIMDbId:
+                        tmdbid, title, year = self.searchTMDbByIMDbId(hasIMDbId)
+                        if tmdbid > 0:
+                            print(tmdbid, title, self.ccfcat, self.year)
+                            return
+                    if not self.checkNameContainsId(torname):
+                        if self.tmdbcat in ['tv', 'movie', 'Other', 'HDTV']:
+                            self.searchTMDb(self.title, self.tmdbcat,
+                                            parseYear, self.cntitle)
+                    self.ccfcat = transToCCFCat(self.tmdbcat, self.ccfcat)
+                    
+                    break
+                except:
+                    attempts += 1
+                    print("TMDb connection failed. Trying %d " % attempts)
+                    time.sleep(3)
+
+
+    def getDetails(self):
+        attempts = 0
+        while attempts < 3:
+            try:
+                if self.tmdbid > 0:
+                    if self.tmdbcat == 'movie':
+                        movie = Movie()
+                        self.tmdbDetails = movie.details(self.tmdbid)
+                    elif self.tmdbcat == 'tv':
+                        tv = TV()
+                        self.tmdbDetails = tv.details(self.tmdbid)
+                break
+            except:
+                attempts += 1
+                print("TMDb connection failed. Trying %d " % attempts)
+                time.sleep(3)
+
+
+    def getGenres(self):
+        ll = []
+        if self.genre_ids:
+            for x in self.genre_ids:
+                s = next((y for y in GENRE_LIST_cn if y['id']==x), None)
+                if s:
+                    ll.append(s['name'])
+        return ll
+
+    def getProductionArea(self):
+        if not self.tmdbDetails:
+            self.getDetails()
+        if self.tmdbcat == 'tv':
+            # print(self.tmdbDetails.origin_country)
+            if self.tmdbDetails and self.tmdbDetails.origin_country:
+                return self.tmdbDetails.origin_country[0]
+            elif 'original_language' in self.tmdbDetails:
+                return self.tmdbDetails['original_language']
+        else:            
+            if self.tmdbDetails and self.tmdbDetails.production_countries:
+                if 'iso_3166_1' in self.tmdbDetails.production_countries[0]:
+                    return self.tmdbDetails.production_countries[0]['iso_3166_1']
+            elif 'original_language' in self.tmdbDetails:
+                return self.tmdbDetails['original_language']
+
+        return ''
+        # if self.tmdbDetails and self.tmdbDetails.production_companies:
+        #     r = self.tmdbDetails.production_companies[0].origin_country
+        # return r
+
     def fixSeasonName(self, seasonStr):
         if re.match(r'^Ep?\d+(-Ep?\d+)?$', seasonStr,
                     flags=re.I) or not seasonStr:
@@ -297,6 +360,11 @@ class TMDbNameParser():
             return list
         else:
             return list
+    
+    def fixTmdbParam(self, tparam):
+        if "year" in tparam and len(tparam["year"]) != 4:
+            del tparam["year"]
+        return tparam
 
     def replaceRomanNum(self, titlestr):
         # no I and X
@@ -361,7 +429,8 @@ class TMDbNameParser():
                 # tv = TV()
                 # results = tv.search(s[1])
                 search = Search()
-                results = search.tv_shows({"query": s[1], "year": str(intyear), "page": 1})
+
+                results = search.tv_shows(self.fixTmdbParam({"query": s[1], "year": str(intyear), "page": 1}))
                 if len(results) > 0:
                     if intyear > 0:
                         if self.season and 'S01' not in self.season:
@@ -382,7 +451,7 @@ class TMDbNameParser():
                 if intyear == 0:
                     results = search.movies({"query": s[1], "page": 1})
                 else:
-                    results = search.movies({"query": s[1], "year": str(intyear), "page": 1})
+                    results = search.movies(self.fixTmdbParam({"query": s[1], "year": str(intyear), "page": 1}))
 
                 if len(results) > 0:
                     result = self.findYearMatch(results, intyear, strict=True)
@@ -407,7 +476,7 @@ class TMDbNameParser():
                 if intyear == 0:
                     results = search.multi({"query": s[1], "page": 1})
                 else:
-                    results = search.multi({"query": s[1], "year": str(intyear), "page": 1})
+                    results = search.multi(self.fixTmdbParam({"query": s[1], "year": str(intyear), "page": 1}))
 
                 if len(results) > 0:
                     result = self.findYearMatch(results, intyear, strict=True)
